@@ -4,7 +4,12 @@ use vars ( '@ISA' );
 
 @ISA = 'Data::Postponed';
 
-sub new { bless [ Data::Postponed::_ByValueOrReference( $_[1] ) ], $_[0] }
+sub new {
+    bless [
+	   Data::Postponed::_ByValueOrReference( $_[1] )
+	  ],
+	    $_[0];
+}
 
 sub DESTROY {} # Don't bother AUTOLOADing this
 
